@@ -235,6 +235,11 @@ void KUriFilterTest::localFiles_data()
     setupColumns();
     addRow( "/", "/", KUriFilterData::LocalDir );
     addRow( "/", "/", KUriFilterData::LocalDir, QStringList( "kshorturifilter" ) );
+    addRow( "//", "/", KUriFilterData::LocalDir );
+    addRow( "///", "/", KUriFilterData::LocalDir );
+    addRow( "////", "/", KUriFilterData::LocalDir );
+    addRow( "///tmp", "/tmp", KUriFilterData::LocalDir );
+
     if (QFile::exists(QDir::homePath() + QLatin1String("/.bashrc")))
         addRow( "~/.bashrc", QDir::homePath()+QStringLiteral("/.bashrc"), KUriFilterData::LocalFile, QStringList( "kshorturifilter" ) );
     addRow( "~", QDir::homePath().toLocal8Bit(), KUriFilterData::LocalDir, QStringList( "kshorturifilter" ), "/tmp" );
@@ -360,8 +365,8 @@ void KUriFilterTest::executables_data()
     addRow( "/I/dont/exist", 0, KUriFilterData::Error, minicliFilters );         //krazy:exclude=spelling
     addRow( "/I/dont/exist#a", 0, KUriFilterData::Error, minicliFilters );       //krazy:exclude=spelling
     addRow( "kbuildsycoca5 --help", "kbuildsycoca5 --help", KUriFilterData::Executable, minicliFilters ); // the args are in argsAndOptions()
-    addRow( "/usr/bin/gs", "/usr/bin/gs", KUriFilterData::Executable, minicliFilters );
-    addRow( "/usr/bin/gs -q -option arg1", "/usr/bin/gs -q -option arg1", KUriFilterData::Executable, minicliFilters ); // the args are in argsAndOptions()
+    addRow( "/bin/sh", "/bin/sh", KUriFilterData::Executable, minicliFilters );
+    addRow( "/bin/sh -q -option arg1", "/bin/sh -q -option arg1", KUriFilterData::Executable, minicliFilters ); // the args are in argsAndOptions()
 
     // Typing 'cp' or any other valid unix command in konq's location bar should result in
     // a search using the default search engine
