@@ -62,9 +62,7 @@ int initLocale()
     setenv("LC_ALL", "en_US.ISO-8859-1", 1);
     unsetenv("KDE_UTF8_FILENAMES");
 #endif
-    setenv("KDEHOME", QFile::encodeName(QDir::homePath() + QString::fromLatin1("/.kde-unit-test")), 1);
-    setenv("XDG_DATA_HOME", QFile::encodeName(QDir::homePath() + QString::fromLatin1("/.kde-unit-test/xdg/local")), 1);
-    setenv("XDG_CONFIG_HOME", QFile::encodeName(QDir::homePath() + QString::fromLatin1("/.kde-unit-test/xdg/config")), 1);
+    setenv("KIOSLAVE_ENABLE_TESTMODE", "1", 1); // ensure the ioslaves call QStandardPaths::setTestModeEnabled(true) too
     setenv("KDE_SKIP_KDERC", "1", 1);
     unsetenv("KDE_COLOR_DEBUG");
     return 0;
@@ -136,6 +134,8 @@ void TestTrash::initTestCase()
     // To avoid a runtime dependency on klauncher
     qputenv("KDE_FORK_SLAVES", "yes");
 
+    QStandardPaths::setTestModeEnabled(true);
+
     m_trashDir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QString::fromLatin1("/Trash");
     qDebug() << "setup: using trash directory " << m_trashDir;
 
@@ -273,7 +273,7 @@ static void checkInfoFile(const QString &infoPath, const QString &origFilePath)
 {
     qDebug() << infoPath;
     QFileInfo info(infoPath);
-    QVERIFY(info.exists());
+    QVERIFY2(info.exists(), qPrintable(infoPath));
     QVERIFY(info.isFile());
     KConfig infoFile(info.absoluteFilePath());
     KConfigGroup group = infoFile.group("Trash Info");
@@ -825,6 +825,7 @@ void TestTrash::copyFileInDirectoryFromTrash()
     copyFromTrash(QString::fromLatin1("trashDirFromHome"), destPath, QString::fromLatin1("testfile"));
     QVERIFY(QFileInfo(destPath).isFile());
     QVERIFY(QFileInfo(destPath).size() == 12);
+    QVERIFY(QFileInfo(destPath).isWritable());
 }
 
 void TestTrash::copyDirectoryFromTrash()
@@ -864,18 +865,64 @@ void TestTrash::moveFromTrash(const QString &fileId, const QString &destPath, co
     QVERIFY(!filesItem.exists());
 
     QVERIFY(QFile::exists(destPath));
+    QVERIFY(QFileInfo(destPath).isWritable());
 }
 
 void TestTrash::moveFileFromTrash()
 {
-    const QString destPath = otherTmpDir() + "fileFromHome_restored";
-    moveFromTrash("fileFromHome", destPath);
-    QVERIFY(QFileInfo(destPath).isFile());
-    QVERIFY(QFileInfo(destPath).size() == 12);
+    const QString fileName = QString::fromLatin1("moveFileFromTrash");
+    const QString filePath = homeTmpDir() + fileName;
+    createTestFile(filePath);
+    const QFile::Permissions origPerms = QFileInfo(filePath).permissions();
+    trashFile(filePath, fileName);
 
-    // trash it again for later
-    const QString fileName = "fileFromHome";
-    trashFile(homeTmpDir() + fileName, fileName);
+    const QString destPath = otherTmpDir() + "fileFromTrash_restored";
+    moveFromTrash(fileName, destPath);
+    const QFileInfo destInfo(destPath);
+    QVERIFY(destInfo.isFile());
+    QCOMPARE(destInfo.size(), 12);
+    QVERIFY(destInfo.isWritable());
+    QCOMPARE(int(destInfo.permissions()), int(origPerms));
+
+    QVERIFY(QFile::remove(destPath));
+}
+
+void TestTrash::moveFileFromTrashToDir_data()
+{
+    QTest::addColumn<QString>("destDir");
+
+    QTest::newRow("home_partition") << homeTmpDir(); // this will trigger a direct renaming
+    QTest::newRow("other_partition") << otherTmpDir(); // this will require a real move
+
+}
+
+void TestTrash::moveFileFromTrashToDir()
+{
+    // Given a file in the trash
+    const QString fileName = QString::fromLatin1("moveFileFromTrashToDir");
+    const QString filePath = homeTmpDir() + fileName;
+    createTestFile(filePath);
+    const QFile::Permissions origPerms = QFileInfo(filePath).permissions();
+    trashFile(filePath, fileName);
+    QVERIFY(!QFile::exists(filePath));
+
+    // When moving it out to a dir
+    QFETCH(QString, destDir);
+    const QString destPath = destDir + "moveFileFromTrashToDir";
+    const QUrl src(QString::fromLatin1("trash:/0-") + fileName);
+    const QUrl dest(QUrl::fromLocalFile(destDir));
+    KIO::Job *job = KIO::move(src, dest, KIO::HideProgressInfo);
+    bool ok = job->exec();
+    QVERIFY2(ok, qPrintable(job->errorString()));
+
+    // Then it should move ;)
+    const QFileInfo destInfo(destPath);
+    QVERIFY(destInfo.isFile());
+    QCOMPARE(destInfo.size(), 12);
+    QVERIFY(destInfo.isWritable());
+    QCOMPARE(int(destInfo.permissions()), int(origPerms));
+
+    QVERIFY(QFile::remove(destPath));
 }
 
 void TestTrash::moveFileInDirectoryFromTrash()
